@@ -2287,10 +2287,6 @@ class GitSubmoduleCmd:
         ''
         >>> GitSubmoduleCmd(dir=git_local_clone.dir).update(init=True, recursive=True)
         ''
-        >>> GitSubmoduleCmd(dir=git_local_clone.dir).update(
-        ...     init=True, filter="blob:none"
-        ... )
-        ''
         >>> GitSubmoduleCmd(dir=git_local_clone.dir).update(force=True)
         ''
         >>> GitSubmoduleCmd(dir=git_local_clone.dir).update(checkout=True)
@@ -2481,7 +2477,7 @@ class GitRemoteCmd:
                 local_flags.append("--no-progress")
         return self.run(
             "rename",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=local_flags + required_flags,
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2508,7 +2504,7 @@ class GitRemoteCmd:
 
         return self.run(
             "remove",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=local_flags + required_flags,
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
